/// @description Player control and logic

if (updates) {
//control is only valid while not grappling
if (!isGrappling) {
	//left right movement
	if (keyboard_check(left)) {
		if (!keyboard_check(right)) {
			if (hspeed > -maxHSpeed) {
				hspeed -= hAcceleration;
			} else {
				hspeed = -maxHSpeed;
			}
			sprite_index = spr_player_run_l;
		} else {
			sprite_index = spr_player_idle_l;
			hspeed /= hFriction;
		}
	}

	if (keyboard_check(right)) {
		if (!keyboard_check(left)) {
			if (hspeed < maxHSpeed) {
				hspeed += hAcceleration;
			} else {
				hspeed = maxHSpeed;
			}
			sprite_index = spr_player_run_r;
		} else {
			sprite_index = spr_player_idle_r;
			hspeed /= hFriction;
		}
	}

	if (!keyboard_check(left) && !keyboard_check(right)) {
		if (sprite_index == spr_player_run_l) {
				sprite_index = spr_player_idle_l;
		}
	
		if (sprite_index == spr_player_run_r) {
				sprite_index = spr_player_idle_r;
		}
		hspeed /= hFriction;
	}

	//jumping + doors
	if (keyboard_check_pressed(jump)) {
		if (onGround) {
			if (instance_number(obj_loadHint) > 0 && !isFading) {
				isFading = 1;
				var door = instance_nearest(x, y, obj_door);
				door.image_index = 1;
				var fade = instance_create_layer(0, 0, "foreground", obj_fade);
				fade.destination = door.destination;
				fade.fadeSpeed = 0.05;
			} else {
				audio_play_sound(snd_jump, 0, 0);
				vspeed = jumpForce;
				onGround = 0;
			}
		}
	}
	//more precise jumping
	if (!keyboard_check(jump) && vspeed < 0 && !padJump) {
		vspeed /= jumpPrecision;
	}

	//gravity handling
	if (place_free(x, y + 1)) {
		gravity = baseGravity;
	
		//jump buffer
		if (alarm[0] == -1) {
			alarm[0] = jumpBufferFrames;
		}
	}
} else {
	//player is in grappling state
	if (pivot == -1) {
		isGrappling = 0;
	} else {
		grappleSine += 0.06;
		if (grappleSine > 6.28) {			//2Pi
			grappleSine -= 6.28;
		}
		
		currentAngle = ((sin(grappleSine) + 1) * 90) + 180;
		
		x = lengthdir_x(grapplingDistance, currentAngle) + pivot.x;
		y = lengthdir_y(grapplingDistance, currentAngle) + pivot.y;
		
		grapplingDistance += (targetGrapplingDistance - grapplingDistance) / 10;
	}
	
	if (mouse_check_button_released(mb_left)) {
		direction = 90;
		speed = 10;
		
		isGrappling = 0;
		pivot = -1;
		grappleSine = 0;
	}
}

//drop coins
if (keyboard_check_pressed(drop)) {
	if (keyboard_check(vk_shift)) {
		if (global.coinCount > 5) {
			repeat (5) {
				instance_create_layer(x, y, "background", obj_droppedCoin);
			}
			
			global.coinCount -= 5;
		} else {
			repeat (global.coinCount) {
				instance_create_layer(x, y, "background", obj_droppedCoin);
			}
			
			global.coinCount = 0;
			maxHSpeed = baseHSpeed
		}
	} else {
		if (global.coinCount > 0) {
			instance_create_layer(x, y, "background", obj_droppedCoin);
			
			global.coinCount--;
		} else {
			maxHSpeed = baseHSpeed
		}
	}
	
	if (global.coinCount != 0) {
		scr_calculateNewPlayerSpeed();
	}
}

//max fall velocity
if (vspeed > maxVSpeed) {
	vspeed = maxVSpeed;
}

//OOB = death
if (x > room_width + OOBMargin ||
	x < -OOBMargin ||
	y > room_height + OOBMargin ||
	y < -OOBMargin) {
		instance_destroy();
}

//remove door tip on leaving door area
if (instance_number(obj_loadHint) > 0) {
	if (!place_meeting(x, y, obj_door)) {
		var hint = instance_nearest(x, y, obj_loadHint);
		hint.killswitch = 1;
	}
}

}